==> qBittorrent-Enhanced-Edition-4.3.8.10.tar.gz: qBittorrent-Enhanced-Edition-release-4.3.8.10/src/gui/trackerentriesdialog.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2019  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QDialog>
#include <QtContainerFwd>

#include "base/settingvalue.h"

namespace BitTorrent
{
    struct TrackerEntry;
}

namespace Ui
{
    class TrackerEntriesDialog;
}

class TrackerEntriesDialog : public QDialog
{
    Q_OBJECT
    Q_DISABLE_COPY(TrackerEntriesDialog)

public:
    explicit TrackerEntriesDialog(QWidget *parent);
    ~TrackerEntriesDialog() override;

    void setTrackers(const QVector<BitTorrent::TrackerEntry> &trackers);
    QVector<BitTorrent::TrackerEntry> trackers() const;

private:
    void saveSettings();
    void loadSettings();

    Ui::TrackerEntriesDialog *m_ui;
    SettingValue<QSize> m_storeDialogSize;
};

==> qBittorrent-Enhanced-Edition-4.4.3.11.tar.gz: qBittorrent-Enhanced-Edition-release-4.4.3.11/src/gui/trackerentriesdialog.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2019  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QDialog>
#include <QtContainerFwd>

#include "base/settingvalue.h"

namespace BitTorrent
{
    struct TrackerEntry;
}

namespace Ui
{
    class TrackerEntriesDialog;
}

class TrackerEntriesDialog : public QDialog
{
    Q_OBJECT
    Q_DISABLE_COPY_MOVE(TrackerEntriesDialog)

public:
    explicit TrackerEntriesDialog(QWidget *parent);
    ~TrackerEntriesDialog() override;

    void setTrackers(const QVector<BitTorrent::TrackerEntry> &trackers);
    QVector<BitTorrent::TrackerEntry> trackers() const;

private:
    void saveSettings();
    void loadSettings();

    Ui::TrackerEntriesDialog *m_ui;
    SettingValue<QSize> m_storeDialogSize;
};
